@@ -13,19 +13,22 @@ USER_AGENT_TEMPLATE = "sqlalchemy/{}"
 def create_clickzetta_client(
         username=None,
         password=None,
-        instance_name=None,
+        instance=None,
         workspace=None,
-        vc_name=None,
-        base_url=None,
+        vcluster=None,
+        service=None,
+        schema=None,
 
 ):
-    login_params = LoginParams(username, password, instance_name)
+
     return Client(
-        login_params=login_params,
+        username=username,
+        password=password,
         workspace=workspace,
-        instance_name=instance_name,
-        vc_name=vc_name,
-        base_url=base_url,
+        instance=instance,
+        vcluster=vcluster,
+        service=service,
+        schema=schema,
     )
 
 
