@@ -510,13 +510,14 @@ class ClickZettaDialect(DefaultDialect):
     ):
         super(ClickZettaDialect, self).__init__(*args, **kwargs)
         self.arraysize = arraysize
-        self.host = None
+        self.service = None
         self.username = None
         self.driver_name = None
-        self.pwd = None
-        self.instance_name = None
+        self.password = None
+        self.instance = None
         self.workspace = None
-        self.vc_name = None
+        self.vcluster = None
+        self.schema = None
 
     @classmethod
     def dbapi(cls):
@@ -524,31 +525,34 @@ class ClickZettaDialect(DefaultDialect):
 
     def create_connect_args(self, url):
         (
-            host,
+            service,
             username,
             driver_name,
-            pwd,
-            instance_name,
+            password,
+            instance,
             workspace,
-            vc_name,
+            vcluster,
+            schema,
         ) = parse_url(url)
 
-        self.host = host
+        self.service = service
         self.arraysize = self.arraysize
         self.username = username
         self.driver_name = driver_name
-        self.pwd = pwd
-        self.instance_name = instance_name
+        self.password = password
+        self.instance = instance
         self.workspace = workspace
-        self.vc_name = vc_name
+        self.vcluster = vcluster
+        self.schema = schema
 
         client = _helpers.create_clickzetta_client(
             username=self.username,
-            password=self.pwd,
-            instance_name=self.instance_name,
+            password=self.password,
+            instance=self.instance,
             workspace=self.workspace,
-            vc_name=self.vc_name,
-            base_url=self.host,
+            vcluster=self.vcluster,
+            service=self.service,
+            schema=self.schema,
         )
         return ([], {"client": client})
 
