@@ -19,29 +19,36 @@ def parse_url(origin_url):
     url = make_url(origin_url)
     query = dict(url.query)
 
-    instance_name = url.host.split('.')[0]
-    length = len(instance_name) + 1
+    instance = url.host.split('.')[0]
+    length = len(instance) + 1
 
-    host = 'https://' + url.host[length:]
+    service = 'https://' + url.host[length:]
     workspace = url.database
     username = url.username
     driver_name = url.drivername
-    pwd = url.password
+    password = url.password
+    schema = None
 
-    if 'virtualcluster' in query or 'virtualCluster' in query:
+    if 'virtualcluster' in query or 'virtualCluster' in query or 'vcluster' in query:
         if 'virtualcluster' in query:
-            vc_name = query.pop('virtualcluster')
+            vcluster = query.pop('virtualcluster')
         elif 'virtualCluster' in query:
-            vc_name = query.pop('virtualCluster')
+            vcluster = query.pop('virtualCluster')
+        else:
+            vcluster = query.pop('vcluster')
     else:
-        raise ValueError('url must have `virtualcluster` parameter.')
+        raise ValueError('url must have `virtualcluster` or `virtualCluster` or `vcluster` parameter.')
+
+    if 'schema' in query:
+        schema = query.pop('schema')
 
     return (
-        host,
+        service,
         username,
         driver_name,
-        pwd,
-        instance_name,
+        password,
+        instance,
         workspace,
-        vc_name,
+        vcluster,
+        schema,
     )
